@@ -47,8 +47,8 @@ def repository_handler(repoent):
     """get repository handler for the given repository entity"""
     # deactivate read security first, potentially needed to get access to
     # path/local_cache
-    session = repoent._cw
-    with session.security_enabled(read=False):
+    cnx = repoent._cw
+    with cnx.security_enabled(read=False):
         try:
             repohdlr = _REPOHDLRS[repoent.eid]
             repohdlr.encoding = repoent.encoding # in case it changed
@@ -58,26 +58,26 @@ def repository_handler(repoent):
                 path = repoent.path
                 if not path:
                     if not repoent.local_cache:
-                        msg = session._('no local access to repository')
+                        msg = cnx._('no local access to repository')
                         raise ValidationError(repoent.eid, {'source_url': msg})
-                    path = join(session.vreg.config.local_repo_cache_root,
+                    path = join(cnx.vreg.config.local_repo_cache_root,
                                 repoent.local_cache)
                 repohdlr = _VCSTYPES[repoent.type](repoent.eid, path,
                                                    repoent.encoding)
             except KeyError:
-                msg = session._('%s is not a known repository type')
+                msg = cnx._('%s is not a known repository type')
                 raise ValidationError(repoent.eid, {'type': msg % repoent.type})
             except ImportError:
-                msg = session._('missing python bindings to support %s repositories')
+                msg = cnx._('missing python bindings to support %s repositories')
                 raise ValidationError(repoent.eid, {'type': msg % repoent.type})
             _REPOHDLRS[repoent.eid] = repohdlr
             return repohdlr
 
 
-def import_content(session, commitevery=1000, raise_on_error=False):
+def import_content(cnx, commitevery=1000, raise_on_error=False):
     """synchronize content of known vcs repositories
     """
-    for vcsrepo in session.execute(
+    for vcsrepo in cnx.execute(
         'Any X,T,U,P,L,SP,E WHERE X is Repository, '
         'X type T, X source_url U, X path P, X local_cache L, '
         'X subpath SP, X encoding E').entities():
@@ -86,21 +86,21 @@ def import_content(session, commitevery=1000, raise_on_error=False):
         except VCSException, ex:
             if raise_on_error:
                 raise
-            session.error(str(ex))
+            cnx.error(str(ex))
             continue
-        import_vcsrepo_content(session, repohdlr, vcsrepo,
+        import_vcsrepo_content(cnx, repohdlr, vcsrepo,
                                commitevery=commitevery,
                                raise_on_error=raise_on_error)
 
 
-def import_vcsrepo_content(session, repohdlr, vcsrepo, commitevery=10,
+def import_vcsrepo_content(cnx, repohdlr, vcsrepo, commitevery=10,
                            raise_on_error=False):
     """synchronize content of given vcs repository"""
     try:
         repohdlr.import_content(vcsrepo, commitevery)
         # give other threads a chance to run: commit will release the cnxset, get
         # it back afterwards
-        session.commit()
+        cnx.commit()
     except Exception:
         if raise_on_error:
             raise
@@ -114,11 +114,10 @@ def import_vcsrepo_content(session, repohdlr, vcsrepo, commitevery=10,
             title = str(vcsrepo)
         repohdlr.exception(
             'error while importing content for vcs repo %s', title)
-        session.rollback()
-    session.set_cnxset()
+        cnx.rollback()
 
 
-def set_at_revision(session, reid, parent_lrevs=None, safetybelt=False):
+def set_at_revision(cnx, reid, parent_lrevs=None, safetybelt=False):
     """at_revision is an internal relation used to know the full content of a
     repository at any revision. This function set this relation for newly
     created revision.
@@ -126,7 +125,7 @@ def set_at_revision(session, reid, parent_lrevs=None, safetybelt=False):
     `parent_lrevs` should be an ordered list of parent revision, the first
     one being the one into which others are merged
     """
-    sql = session.system_sql
+    sql = cnx.system_sql
     if safetybelt:
         sql("DELETE FROM at_revision_relation WHERE eid_to='%s'" % reid)
     # link to version content generated by this revision
@@ -174,7 +173,7 @@ def set_at_revision(session, reid, parent_lrevs=None, safetybelt=False):
             % {'reid': reid, 'plrev': parent_lrevs.pop(0)})
 
 
-def import_revision(session, repoeid, date, **kwargs):
+def import_revision(cnx, repoeid, date, **kwargs):
     """import a new revision from a repository"""
     args = {'date': date}
     args['repoeid'] = repoeid
@@ -186,30 +185,30 @@ def import_revision(session, repoeid, date, **kwargs):
     precs = kwargs['precursors']
     if precs:
         args['precursor'] = precs[0]
-    reveid = session.execute(queries.new_revision_rql(prevs, precs, True), args)[0][0]
+    reveid = cnx.execute(queries.new_revision_rql(prevs, precs, True), args)[0][0]
     # complete other parents & precursors relations
     if len(prevs) > 1:
         for preveid in prevs[1:]:
-            session.execute('SET R parent_revision PR WHERE R eid %(r)s, PR eid %(pr)s',
-                            {'r': reveid, 'pr': preveid})
+            cnx.execute('SET R parent_revision PR WHERE R eid %(r)s, PR eid %(pr)s',
+                        {'r': reveid, 'pr': preveid})
     if len(precs) > 1:
         for preceid in precs[1:]:
-            session.execute('SET R obsoletes PREC WHERE R eid %(r)s, PREC eid %(pr)s',
-                            {'r': reveid, 'pr': preceid})
+            cnx.execute('SET R obsoletes PREC WHERE R eid %(r)s, PREC eid %(pr)s',
+                        {'r': reveid, 'pr': preceid})
     return reveid
 
-def import_versioned_file(session, repoeid, date, directory, name):
+def import_versioned_file(cnx, repoeid, date, directory, name):
     """import a version controlled file from a repository"""
     args = {'directory': directory, 'name': name, 'repoeid': repoeid}
-    return session.execute(
+    return cnx.execute(
         'INSERT VersionedFile X: X directory %(directory)s, '
         'X name %(name)s, X from_repository R '
         'WHERE R eid %(repoeid)s', args)[0][0]
 
-def import_version_content(session, repoeid, reveid, upath, date, **kwargs):
+def import_version_content(cnx, repoeid, reveid, upath, date, **kwargs):
     """import a new file revision from a repository"""
-    repohdlr = repository_handler(session.entity_from_eid(repoeid, 'Repository'))
-    vfeid = repohdlr.vf_eid(session, upath, date)
+    repohdlr = repository_handler(cnx.entity_from_eid(repoeid, 'Repository'))
+    vfeid = repohdlr.vf_eid(cnx, upath, date)
     # done in a hook but doing it here as well to avoid an additional query to
     # lookup filename
     mt, enc = guess_mimetype_and_encoding(
@@ -225,17 +224,17 @@ def import_version_content(session, repoeid, reveid, upath, date, **kwargs):
             args[inlinerel] = kwargs[inlinerel]
             rql += ', X %s %%(%s)s' % (inlinerel, inlinerel)
     rql += ' WHERE REV eid %(rev)s, VF eid %(vf)s'
-    return session.execute(rql, args)[0][0], vfeid
+    return cnx.execute(rql, args)[0][0], vfeid
 
 
-def import_deleted_version_content(session, repoeid, reveid, upath, date):
+def import_deleted_version_content(cnx, repoeid, reveid, upath, date):
     """import a new deleted file revision from a repository"""
-    repohdlr = repository_handler(session.entity_from_eid(repoeid, 'Repository'))
-    vfeid = repohdlr.vf_eid(session, upath, date)
+    repohdlr = repository_handler(cnx.entity_from_eid(repoeid, 'Repository'))
+    vfeid = repohdlr.vf_eid(cnx, upath, date)
     args = {'vf': vfeid, 'rev': reveid}
     rql = ('INSERT DeletedVersionContent X: X from_revision REV, X content_for VF '
            ' WHERE REV eid %(rev)s, VF eid %(vf)s')
-    return session.execute(rql, args)[0][0], vfeid
+    return cnx.execute(rql, args)[0][0], vfeid
 
 
 from cubicweb import QueryError
@@ -244,11 +243,11 @@ from cubicweb.server.sources import storages
 class VCSStorage(storages.Storage):
     """store Bytes attribute value in a version content system"""
 
-    def callback(self, source, session, value):
+    def callback(self, source, cnx, value):
         repoeid, dir, name, revnum = source.binary_to_str(value).split('\x01')
         repoeid = int(repoeid)
         try:
-            vcsrepohdlr = repository_handler(session.entity_from_eid(repoeid, 'Repository'))
+            vcsrepohdlr = repository_handler(cnx.entity_from_eid(repoeid, 'Repository'))
         except Exception, ex:
             source.critical("can't get repository handler for eid %s: %s",
                             repoeid, ex, exc_info=sys.exc_info())
@@ -269,11 +268,11 @@ class VCSStorage(storages.Storage):
         except KeyError:
             pass
         else:
-            session = entity._cw
+            cnx = entity._cw
             # don't create vcs transaction if the revision is being imported
             # from the vcs repository
             try:
-                repoeid, dir, name, revnum = session.transaction_data['vcs_importing']
+                repoeid, dir, name, revnum = cnx.transaction_data['vcs_importing']
             except KeyError:
                 vf = entity._vc_vf()
                 repoeid = vf.repository.eid
@@ -281,7 +280,7 @@ class VCSStorage(storages.Storage):
                 dir = vcsrepohdlr.encode(vf.directory)
                 name = vcsrepohdlr.encode(vf.name)
                 revnum = transaction.rev
-                vcsrepohdlr.add_versioned_file_content(session, transaction,
+                vcsrepohdlr.add_versioned_file_content(cnx, transaction,
                                                        vf, entity, data)
             vckey = (str(repoeid), dir, name, str(revnum))
             entity.cw_edited[attr] = Binary('\x01'.join(vckey))
