@@ -8,7 +8,6 @@ __docformat__ = "restructuredtext en"
 import os.path as osp
 
 from logilab.common.decorators import cached, clear_cache
-from logilab.common.compat import any
 from logilab.common.deprecation import deprecated
 
 from cubicweb import QueryError, Binary, Unauthorized
@@ -105,7 +104,7 @@ class Repository(AnyEntity):
         return latestrev
 
     def heads_rset(self):
-        """return a result set containing head revision (eg revisions without
+        """return a result set containing head revisions (i.e. revisions without
         children)
         """
         return self._cw.execute(
