@@ -137,7 +137,7 @@ class VCSFileStartHook(hook.Hook):
 class VCSetAtRevisionOp(hook.Operation):
 
     def precommit_event(self):
-        bridge.set_at_revision(self.session, self.revision.eid)
+        bridge.set_at_revision(self.cnx, self.revision.eid)
 
 
 class VCTransactionOp(hook.LateOperation):
@@ -187,35 +187,35 @@ class AddRevisionHook(hook.Hook):
 
     def __call__(self):
         entity = self.entity
-        session = self._cw
+        cnx = self._cw
         # new revision to be created, set a temporary value if necessary
         revision = entity.cw_edited.setdefault('revision', 0)
         # skip further processing if the revision is being imported from the
         # vcs repository
-        if session.is_internal_session:
+        if cnx.is_internal_session:
             return
         try:
             vcsrepoeid = entity.cw_attr_cache['from_repository']
         except KeyError:
-            vcsrepoeid = session.transaction_data.pop('vcsrepoeid', None)
+            vcsrepoeid = cnx.transaction_data.pop('vcsrepoeid', None)
             if vcsrepoeid is None:
                 raise missing_relation_error(entity, 'from_repository')
         if revision > 0: # set to 0 by hook
             raise QueryError("can't specify revision")
-        transactions = session.transaction_data.setdefault('vctransactions', {})
+        transactions = cnx.transaction_data.setdefault('vctransactions', {})
         # should not have multiple transaction on the same repository
         if vcsrepoeid in transactions:
             raise QueryError('already processing a new revision')
         vcsrepohdlr = bridge.repository_handler(
-            session.entity_from_eid(vcsrepoeid))
-        transaction = vcsrepohdlr.revision_transaction(session, entity)
+            cnx.entity_from_eid(vcsrepoeid))
+        transaction = vcsrepohdlr.revision_transaction(cnx, entity)
         transaction.reveid = entity.eid
         transactions[vcsrepoeid] = transaction
         entity.cw_edited['revision'] = transaction.rev
         # VCTransactionOp is a late operation, but we shouldn't wait that much
         # to set at_revision relation, so use two distinct operation
-        VCSetAtRevisionOp(session, revision=entity)
-        VCTransactionOp(session, revision=entity, transaction=transaction)
+        VCSetAtRevisionOp(cnx, revision=entity)
+        VCTransactionOp(cnx, revision=entity, transaction=transaction)
 
 
 class AddVersionContentHook(hook.Hook):
@@ -458,8 +458,8 @@ def _refresh_repos(repo, eids=None, bridge=bridge):
       * None for all vcs repos
       * a list of integers for specific vcs repos
     '''
-    with repo.internal_session(safe=True) as session:
-        config = session.vreg.config
+    with repo.internal_cnx() as cnx:
+        config = cnx.vreg.config
         rql = ('Any R, RT, RE, RLC, RSU, RP, RIRC WHERE R is Repository, '
                'NOT (R local_cache NULL AND R path NULL),'
                'R type RT, R encoding RE, R local_cache RLC, R source_url RSU, R path RP,'
@@ -473,7 +473,7 @@ def _refresh_repos(repo, eids=None, bridge=bridge):
                 kwargs = {'x': eids}
             else:
                 rql += ', R eid IN (%s)' % ','.join(str(eid) for eid in eids)
-        reposrset = session.execute(rql, kwargs)
+        reposrset = cnx.execute(rql, kwargs)
         for vcsrepo in reposrset.entities():
             # watch for repository being shut-down, our thread may:
             # * not receive the KeyboardInterrupt or shutdown signal
@@ -483,10 +483,10 @@ def _refresh_repos(repo, eids=None, bridge=bridge):
             try:
                 repohdlr = bridge.repository_handler(vcsrepo)
             except bridge.VCSException, ex:
-                session.error(str(ex))
+                cnx.error(str(ex))
                 continue
             except Exception:
-                session.exception('error while retrieving handler for %s',
+                cnx.exception('error while retrieving handler for %s',
                                   vcsrepo.eid)
                 continue
             if (config['repository-import'] or vcsrepo.import_revision_content) \
@@ -503,7 +503,7 @@ def _refresh_repos(repo, eids=None, bridge=bridge):
             if (config['repository-import']
                 and vcsrepo.cw_metainformation()['source']['uri'] == 'system'):
                 bridge.import_vcsrepo_content(
-                    session, repohdlr, vcsrepo,
+                    cnx, repohdlr, vcsrepo,
                     commitevery=config.get('check-revision-commit-every', 1))
 
 
@@ -525,9 +525,9 @@ class VCSRepoNotifHook(hook.Hook):
         def callback(msg):
             self.debug('received notification: %s', ' '.join(msg))
             msg = msg[-1]
-            with self.repo.internal_session(safe=True) as session:
+            with self.repo.internal_cnx() as cnx:
                 for suffix in ('', '/'):
-                    rset = session.execute('Any R WHERE R source_url U, '
+                    rset = cnx.execute('Any R WHERE R source_url U, '
                                             'R source_url LIKE %(u)s',
                                             {'u': '%/'+msg+suffix})
                     if rset:
@@ -536,7 +536,7 @@ class VCSRepoNotifHook(hook.Hook):
                     assert len(rset) == 1, 'found multiple repos for "%s"'%msg
                     eid = rset[0][0]
                     self.debug('Calling refresh service for repo %s', eid)
-                    session.call_service('refresh_repository', eids=[eid])
+                    cnx.call_service('refresh_repository', eids=[eid])
                 else:
                     self.debug('No repo for %s', msg)
 
