@@ -15,11 +15,13 @@ from os.path import split, exists, dirname
 from datetime import datetime
 from contextlib import contextmanager
 import time
+import re
 
 from mercurial import (hg, ui, context, util, encoding,
                        commands as hgcmd, phases, obsolete)
 from mercurial.node import nullid, short as short_hex
 from mercurial import scmutil
+from mercurial.__version__ import version as hgversion
 
 from logilab.common import tempattr
 
@@ -29,6 +31,8 @@ from cubicweb.server.ssplanner import EditedEntity
 from cubes.vcsfile import repo, bridge
 from cubes.vcsfile.entities import remove_authinfo
 
+hg31 = tuple(int(x) for x in re.split('[^0-9]+', hgversion)[:2]) >= (3, 1)
+
 _DELETED = object()
 
 def monkeypatch_mercurial_url():
@@ -175,10 +179,10 @@ class HGRepository(repo.VCSRepository):
     def import_content(self, repoentity, commitevery=1000):
         """import content from the mercurial repository"""
         assert self.eid == repoentity.eid
-        session = repoentity._cw
+        cnx = repoentity._cw
         if not exists(self.path):
             self.pull_or_clone_cache(repoentity.source_url,
-                                     session.vreg.config)
+                                     cnx.vreg.config)
 
         with force_mercurial_utf8():
             try:
@@ -190,8 +194,11 @@ class HGRepository(repo.VCSRepository):
                 self.exception('Impossible to open repository %s (%s)', self, ex)
                 return
 
-            knownheads = [(str(r.changeset), r.revision)
-                          for r in repoentity.heads_rset().entities()]
+            rset = cnx.execute(
+                    'Any CSET, REV WHERE R eid %(r)s, X from_repository R, '
+                    'NOT CREV parent_revision X, X changeset CSET, X revision REV',
+                    {'r': self.eid})
+            knownheads = [(str(r[0]), r[1]) for r in rset]
 
             # detect stripped branches
             needsstrip = False
@@ -202,16 +209,16 @@ class HGRepository(repo.VCSRepository):
                     self.warning('%s: strip detected. %s is unknown in local cache',
                                  self.path, cset)
             if not needsstrip:
-                incoming = repo.revs("not ::%ls", [cset for cset, _rev in knownheads])
+                incoming = list(repo.revs("not ::%ls", [cset for cset, _rev in knownheads]))
                 if incoming:
-                    needsrenumbering = session.execute('Any R WHERE R is Revision, '
-                                                       'R from_repository REPO, '
-                                                       'REPO eid %%(reid)s, R revision IN (%s)'
-                                                       % ','.join([str(rev) for rev in incoming]),
-                                                       {'reid': repoentity.eid})
+                    needsrenumbering = cnx.execute('Any R WHERE R is Revision, '
+                                                   'R from_repository REPO, '
+                                                   'REPO eid %%(reid)s, R revision IN (%s)'
+                                                   % ','.join([str(rev) for rev in incoming]),
+                                                   {'reid': repoentity.eid})
                 if not needsrenumbering:
                     for cset, rev in knownheads:
-                        if repo.revs("id(%s)" % str(cset)) != [rev]:
+                        if rev not in repo.revs("id(%s)" % str(cset)):
                             needsrenumbering = True
                             break
 
@@ -220,10 +227,10 @@ class HGRepository(repo.VCSRepository):
                              repoentity.dc_title(), self.path)
                 # clean all 'revision' attribute to please unicity
                 # constraint when renumbering
-                session.execute('SET R revision -1-REV WHERE R revision REV, R from_repository REPO, '
-                                'REPO eid %(reid)s', {'reid': repoentity.eid})
-                revs = session.execute('Any R WHERE R is Revision, R from_repository REPO, '
-                                       'REPO eid %(reid)s', {'reid': repoentity.eid})
+                cnx.execute('SET R revision -1-REV WHERE R revision REV, R from_repository REPO, '
+                            'REPO eid %(reid)s', {'reid': repoentity.eid})
+                revs = cnx.execute('Any R WHERE R is Revision, R from_repository REPO, '
+                                   'REPO eid %(reid)s', {'reid': repoentity.eid})
                 for reventity in revs.entities():
                     if str(reventity.changeset) not in repo:
                         reventity.cw_delete()
@@ -231,29 +238,29 @@ class HGRepository(repo.VCSRepository):
                         rev = repo[str(reventity.changeset)].rev()
                         reventity.cw_set(revision=rev)
 
-                if session.execute('Revision R WHERE R revision < 0, R from_repository REPO, '
-                                       'REPO eid %(reid)s', {'reid': repoentity.eid}):
-                    session.rollback()
+                if cnx.execute('Revision R WHERE R revision < 0, R from_repository REPO, '
+                               'REPO eid %(reid)s', {'reid': repoentity.eid}):
+                    cnx.rollback()
                     self.error('Abort stripping and renumbering of Repository %s: '
                                'detected remaining Revision with negative revision number',
                                repoentity.eid)
                     return
-                session.commit()
-                session.set_cnxset()
-                session.execute(
+                cnx.commit()
+                cnx.execute(
                     'DELETE VersionedFile X WHERE X from_repository R, R eid %(r)s, '
                     'NOT VC content_for X', {'r': repoentity.eid})
-                # commit and give a chance to threads waiting for a cnxset
-                # by freeing it then reacquiring it
-                session.commit()
-                session.set_cnxset()
+                cnx.commit()
 
             # update phases and visibility of already known revisions
-            self.update_phases(session, repoentity, repo)
-            self.update_hidden(session, repoentity, repo)
+            self.update_phases(cnx, repoentity, repo)
+            self.update_hidden(cnx, repoentity, repo)
             # XXX we need to update obsolescence markers without new revision
             #     involved.
-            knownheads = [str(r.changeset) for r in repoentity.heads_rset().entities()]
+            rset = cnx.execute(
+                    'Any CSET WHERE R eid %(r)s, X from_repository R, '
+                    'NOT CREV parent_revision X, X changeset CSET',
+                    {'r': self.eid})
+            knownheads = [str(r[0]) for r in rset]
             missing = list(repo.revs("not ::%ls", knownheads))
             missing.sort()
             while missing:
@@ -264,54 +271,48 @@ class HGRepository(repo.VCSRepository):
                         self.critical('error while importing revision %s of %s',
                                       rev, self.path, exc_info=True)
                         raise
-                # give a chance to threads waiting for a cnxset by
-                # freeing it then reacquiring it
-                session.commit()
-                session.set_cnxset()
+                cnx.commit()
                 del missing[:commitevery] # pop iterated value
             # if missing was empty we still need to commit phases and visibility changes
-            # give a chance to threads waiting for a cnxset by
-            # freeing it then reacquiring it
-            session.commit()
-            session.set_cnxset()
+            cnx.commit()
 
-    def update_phases(self, session, repoentity, repo):
+    def update_phases(self, cnx, repoentity, repo):
         """ update all phases (this potentially affects all revs since
         phase changes are not transactional) """
         notpublic = set(str(ctx) for ctx in repo.set('not public()'))
         if notpublic:
-            session.execute('SET R phase "public" WHERE NOT R changeset IN (%s),'
-                            'NOT R phase "public", R from_repository REPO,'
-                            'REPO eid %%(repo)s' %
-                            ','.join(repr(rev) for rev in notpublic),
-                            {'repo': repoentity.eid})
+            cnx.execute('SET R phase "public" WHERE NOT R changeset IN (%s),'
+                        'NOT R phase "public", R from_repository REPO,'
+                        'REPO eid %%(repo)s' %
+                        ','.join(repr(rev) for rev in notpublic),
+                        {'repo': repoentity.eid})
             for phase in ('draft', 'secret'):
                 revs = set(str(ctx) for ctx in repo.set('%s()' % phase))
                 if revs:
-                    session.execute('SET R phase "%s" WHERE R changeset IN (%s),'
-                                    'NOT R phase "%s", R from_repository REPO,'
-                                    'REPO eid %%(repo)s' %
-                                    (phase, ','.join(repr(rev) for rev in revs), phase),
-                                    {'repo': repoentity.eid})
+                    cnx.execute('SET R phase "%s" WHERE R changeset IN (%s),'
+                                'NOT R phase "%s", R from_repository REPO,'
+                                'REPO eid %%(repo)s' %
+                                (phase, ','.join(repr(rev) for rev in revs), phase),
+                                {'repo': repoentity.eid})
         else:
-            session.execute('SET R phase "public" WHERE R from_repository REPO, '
-                            'NOT R phase "public", REPO eid %(repo)s',
-                            {'repo': repoentity.eid})
+            cnx.execute('SET R phase "public" WHERE R from_repository REPO, '
+                        'NOT R phase "public", REPO eid %(repo)s',
+                        {'repo': repoentity.eid})
 
 
 
-    def update_hidden(self, session, repoentity, repo):
+    def update_hidden(self, cnx, repoentity, repo):
         """ maintain hidden status for all revs """
-        oldhidden = set(num for num, in session.execute('Any N WHERE R hidden True, '
-                                                        'R from_repository H, '
-                                                        'R revision N, H eid %(hg)s',
-                                                        {'hg': repoentity.eid}).rows)
+        oldhidden = set(num for num, in cnx.execute('Any N WHERE R hidden True, '
+                                                    'R from_repository H, '
+                                                    'R revision N, H eid %(hg)s',
+                                                    {'hg': repoentity.eid}).rows)
         newhidden = set(repo.revs('hidden()'))
         hide = newhidden - oldhidden
         show = oldhidden - newhidden
         for revs, setto in ((hide, 'True'), (show, 'False')):
             if revs:
-                session.execute('SET R hidden %s WHERE R from_repository H,'
+                cnx.execute('SET R hidden %s WHERE R from_repository H,'
                                 'H eid %%(hg)s, R revision IN (%s)' %
                                 (setto, ','.join(str(revnum) for revnum in revs)),
                                 {'hg': repoentity.eid})
@@ -336,13 +337,13 @@ class HGRepository(repo.VCSRepository):
                     'p': str(ctx)}
             for succ in iter_direct_known_successors(ctx):
                 data['s'] = str(succ)
-                session.execute(RQL, data)
+                cnx.execute(RQL, data)
 
 
     def import_revision(self, repoentity, repo, i):
         self.info('importing revision %s from %s', i, repoentity.dc_title())
-        session = repoentity._cw
-        execute = session.execute
+        cnx = repoentity._cw
+        execute = cnx.execute
         node = repo.changelog.node(i)
         changeset = unicode(short_hex(node))
         if execute('Any X WHERE X from_repository R, R eid %(repo)s, X changeset %(cs)s',
@@ -388,7 +389,7 @@ class HGRepository(repo.VCSRepository):
                 % ','.join("'%s'"%cs for cs in parent_changesets),
                 {'r': self.eid})
         revdata['parents'] = [r[0] for r in parents]
-        reveid = bridge.import_revision(session, self.eid, **revdata)
+        reveid = bridge.import_revision(cnx, self.eid, **revdata)
         if not repoentity.import_revision_content:
             return
         changes = repo.status(ctx.parents()[0].node(), ctx.node())[:3]
@@ -398,27 +399,27 @@ class HGRepository(repo.VCSRepository):
             upath = unicode(path, self.encoding, 'replace')
             if not (path_filter is None or upath.startswith(path_filter)):
                 continue
-            self._import_version_content(session, changeset, reveid, removed,
+            self._import_version_content(cnx, changeset, reveid, removed,
                                          path, upath, date, repo, ctx)
         for path in removed:
             upath = unicode(path, self.encoding, 'replace')
             if not (path_filter is None or upath.startswith(path_filter)):
                 continue
-            bridge.import_deleted_version_content(session, self.eid, reveid,
+            bridge.import_deleted_version_content(cnx, self.eid, reveid,
                                                   upath, date)
         parent_idx = dict( ((cs, lrev) for _, cs, lrev in parents) )
         parent_lrevs = [parent_idx[cs] for cs in parent_changesets]
-        bridge.set_at_revision(session, reveid, parent_lrevs)
+        bridge.set_at_revision(cnx, reveid, parent_lrevs)
 
-    def _import_version_content(self, session, changeset, reveid, removed, path, upath,
+    def _import_version_content(self, cnx, changeset, reveid, removed, path, upath,
                                 date, repo, ctx):
         directory, fname = split(path)
-        session.transaction_data['vcs_importing'] = self.eid, directory, fname, changeset
+        cnx.transaction_data['vcs_importing'] = self.eid, directory, fname, changeset
         filectx = ctx[path]
         vcdata = {'data': Binary(filectx.data())}
         renameinfo = filectx.renamed()
         if renameinfo:
-            pvc, oldfile = self._renamed_vc_rset(session, repo, renameinfo)
+            pvc, oldfile = self._renamed_vc_rset(cnx, repo, renameinfo)
             if pvc:
                 assert len(pvc) == 1
                 if oldfile in removed:
@@ -429,20 +430,20 @@ class HGRepository(repo.VCSRepository):
                 self.error('detected copy or rename of %s@%s but unable'
                            ' to find associated version content',
                            oldfile, pvc.args['cs'])
-        return bridge.import_version_content(session, self.eid, reveid, upath,
+        return bridge.import_version_content(cnx, self.eid, reveid, upath,
                                              date, **vcdata)
 
-    def _renamed_vc_rset(self, session, repo, renameinfo):
+    def _renamed_vc_rset(self, cnx, repo, renameinfo):
         oldfile, fileid = renameinfo
         pfctx = repo.filectx(oldfile, fileid=fileid)
         pcs = short_hex(pfctx.node())
         dir, name = split(unicode(oldfile, self.encoding, 'replace'))
-        return session.execute('VersionContent X WHERE '
-                               'X from_revision REV, REV changeset %(cs)s, '
-                               'REV from_repository R, R eid %(r)s, '
-                               'X content_for VF, VF directory %(dir)s, VF name %(name)s',
-                               {'cs':  pcs, 'r': self.eid,
-                                'dir': dir, 'name': name}), oldfile
+        return cnx.execute('VersionContent X WHERE '
+                           'X from_revision REV, REV changeset %(cs)s, '
+                           'REV from_repository R, R eid %(r)s, '
+                           'X content_for VF, VF directory %(dir)s, VF name %(name)s',
+                           {'cs':  pcs, 'r': self.eid,
+                            'dir': dir, 'name': name}), oldfile
 
     def hgrepo(self):
         repo = hg.repository(ui.ui(), self.path)
@@ -455,21 +456,25 @@ class HGRepository(repo.VCSRepository):
         ctx = self.hgrepo().changectx(rev)
         return Binary(ctx[path].data())
 
-    def revision_transaction(self, session, entity):
+    def revision_transaction(self, cnx, entity):
         """open a transaction to create a new revision corresponding to the
         given entity
         """
-        return HGTransaction(self, session, entity)
+        return HGTransaction(self, cnx, entity)
 
-    def add_versioned_file_content(self, session, transaction, vf, entity,
+    def add_versioned_file_content(self, cnx, transaction, vf, entity,
                                    data):
         """add a new revision of a versioned file"""
         vfpath = self.encode(vf.path)
-        transaction.changes[vfpath] = context.memfilectx(
-            vfpath, data.getvalue(), islink=False, isexec=False, copied=None)
+        if hg31:
+            transaction.changes[vfpath] = context.memfilectx(
+                transaction.repo, vfpath, data.getvalue(), islink=False, isexec=False, copied=None)
+        else:
+            transaction.changes[vfpath] = context.memfilectx(
+                vfpath, data.getvalue(), islink=False, isexec=False, copied=None)
         return vf.path
 
-    def add_versioned_file_deleted_content(self, session, transaction, vf,
+    def add_versioned_file_deleted_content(self, cnx, transaction, vf,
                                            entity):
         """add a new revision of a just deleted versioned file"""
         transaction.changes[self.encode(vf.path)] = _DELETED
@@ -477,9 +482,9 @@ class HGRepository(repo.VCSRepository):
 
 
 class HGTransaction(object):
-    def __init__(self, repohdlr, session, revision):
+    def __init__(self, repohdlr, cnx, revision):
         self.repohdlr = repohdlr
-        self.session = session
+        self.cnx = cnx
         self.revision = revision
         self.repo = repohdlr.hgrepo()
         # see http://mercurial.selenic.com/wiki/LockingDesign
@@ -561,18 +566,18 @@ class HGTransaction(object):
             node = self.repo.commitctx(ctx)
             # update revision's record to set correct changeset
             #
-            # take care, self.repo != self.session.repo (eg mercurial repo
-            # instance / rql repository)
-            source = self.session.repo.system_source
+            # take care, self.repo != self.cnx.repo (mercurial repo
+            # instance vs rql repository)
+            source = self.cnx.repo.system_source
             # remove previous cached value to only save the changeset
             with tempattr(revision, 'cw_edited', EditedEntity(revision)) as rev:
                 rev.cw_edited['changeset'] = unicode(short_hex(node))
                 rev.cw_edited['phase'] = unicode(self.repo[node].phasestr())
-                source.update_entity(self.session, rev)
+                source.update_entity(self.cnx, rev)
             # we need to explicitly commit the connection to the database since
             # this method is actually called from a postcommit event, i.e. once
             # cnxset has already been commited
-            self.session.cnxset.connection('system').commit()
+            self.cnx.cnxset.commit()
             # XXX restore entity's dict?
             self.rollback()
         finally:
