@@ -64,7 +64,7 @@ class Revision(EntityType):
     __permissions__ = {
         'read':   ('managers', 'users', 'guests'),
         'add':    ('managers', 'users',),
-        'update': ('managers', 'owners'),
+        'update': (),
         'delete': (),
         }
     __unique_together__ = [('from_repository', 'revision'),
@@ -215,6 +215,9 @@ class vc_rename(RelationDefinition):
     cardinality = '?*'
 
 class obsoletes(RelationDefinition):
+    __permissions__ = {'read': ('managers', 'users', 'guests'),
+                       'add': (),
+                       'delete': ()}
     subject = 'Revision'
     object = 'Revision'
 
