@@ -15,9 +15,8 @@ class AutomaticWebTest(testlib.AutomaticWebTest):
                     'DeletedVersionContent',
                     'VersionContent'))
 
-    def custom_populate(self, how_many, cursor):
-        req = self.request()
-        req.create_entity('Repository', type=u'mercurial',
+    def custom_populate(self, how_many, cnx):
+        cnx.create_entity('Repository', type=u'mercurial',
                           path=unicode(osp.join(self.datadir, 'testrepohg')),
                           encoding=u'latin1')
 
