@@ -7,7 +7,7 @@
 __docformat__ = "restructuredtext en"
 _ = unicode
 
-from logilab.mtconverter import TransformError, xml_escape
+from logilab.mtconverter import TransformError, xml_escape, is_text_mimetype
 
 from cubicweb import Unauthorized, tags
 from cubicweb.mttransforms import ENGINE
@@ -246,6 +246,11 @@ class VFPrimaryView(primary.PrimaryView):
             self.field('head', head.rev.view('incontext'))
             if contenttype.startswith('image/'):
                 self.wview('image', head.cw_rset, row=head.cw_row)
+            elif is_text_mimetype(contenttype):
+                self.w(u'<pre>')
+                udata = unicode(head.data.getvalue(), head.data_encoding)
+                self.w(xml_escape(udata))
+                self.w(u'</pre>')
             else:
                 try:
                     if ENGINE.has_input(contenttype):
